filter

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 23, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FromPredicate added in v0.4.0

func FromPredicate(base afero.Fs, pred Predicate) afero.Fs

func NewFs

func NewFs(base afero.Fs, filter Filter) afero.Fs

Types

type File

type File struct {
	// contains filtered or unexported fields
}

func (*File) Close

func (f *File) Close() error

Close implements afero.File.

func (*File) Name

func (f *File) Name() string

Name implements afero.File.

func (*File) Read

func (f *File) Read(p []byte) (n int, err error)

Read implements afero.File.

func (*File) ReadAt

func (f *File) ReadAt(p []byte, off int64) (n int, err error)

ReadAt implements afero.File.

func (*File) Readdir

func (f *File) Readdir(count int) (res []fs.FileInfo, err error)

Readdir implements afero.File.

func (*File) Readdirnames

func (f *File) Readdirnames(n int) (names []string, err error)

Readdirnames implements afero.File.

func (*File) Seek

func (f *File) Seek(offset int64, whence int) (int64, error)

Seek implements afero.File.

func (*File) Stat

func (f *File) Stat() (fs.FileInfo, error)

Stat implements afero.File.

func (*File) Sync

func (f *File) Sync() error

Sync implements afero.File.

func (*File) Truncate

func (f *File) Truncate(size int64) error

Truncate implements afero.File.

func (*File) Write

func (f *File) Write(p []byte) (n int, err error)

Write implements afero.File.

func (*File) WriteAt

func (f *File) WriteAt(p []byte, off int64) (n int, err error)

WriteAt implements afero.File.

func (*File) WriteString

func (f *File) WriteString(s string) (ret int, err error)

WriteString implements afero.File.

type Filter added in v0.4.0

type Filter func(op.Operation) error

Filter evaluates a filesystem operation and returns an error if it should be blocked.

type Fs

type Fs struct {
	// contains filtered or unexported fields
}

func (*Fs) Chmod

func (f *Fs) Chmod(name string, mode fs.FileMode) error

Chmod implements afero.Fs.

func (*Fs) Chown

func (f *Fs) Chown(name string, uid int, gid int) error

Chown implements afero.Fs.

func (*Fs) Chtimes

func (f *Fs) Chtimes(name string, atime time.Time, mtime time.Time) error

Chtimes implements afero.Fs.

func (*Fs) Create

func (f *Fs) Create(name string) (afero.File, error)

Create implements afero.Fs.

func (*Fs) Mkdir

func (f *Fs) Mkdir(name string, perm fs.FileMode) error

Mkdir implements afero.Fs.

func (*Fs) MkdirAll

func (f *Fs) MkdirAll(path string, perm fs.FileMode) error

MkdirAll implements afero.Fs.

func (*Fs) Name

func (f *Fs) Name() string

Name implements afero.Fs.

func (*Fs) Open

func (f *Fs) Open(name string) (afero.File, error)

Open implements afero.Fs.

func (*Fs) OpenFile

func (f *Fs) OpenFile(name string, flag int, perm fs.FileMode) (afero.File, error)

OpenFile implements afero.Fs.

func (*Fs) Remove

func (f *Fs) Remove(name string) error

Remove implements afero.Fs.

func (*Fs) RemoveAll

func (f *Fs) RemoveAll(path string) error

RemoveAll implements afero.Fs.

func (*Fs) Rename

func (f *Fs) Rename(oldname string, newname string) error

Rename implements afero.Fs.

func (*Fs) Stat

func (f *Fs) Stat(name string) (fs.FileInfo, error)

Stat implements afero.Fs.

type Predicate

type Predicate func(op.Operation) bool

Predicate evaluates a filesystem operation and returns true if it should be allowed.

Jump to